@@ -1,10 +1,11 @@
+import json
+import time
+
+import oauthlib
 from oauthlib.oauth2 import BackendApplicationClient
 from requests_oauthlib import OAuth2Session
-import oauthlib
-import AIH_SDK.AIHExceptions as AIHE
-import time
-import json
 
+import AIH_SDK.AIHExceptions as AIHE
 
 
 class AIHClient:
@@ -92,7 +93,7 @@ class AIHClient:
         try:
             return response.json()
         except:
-            raise AIHE.AIHClientException(f'Cannot interpret response as JSON. API might be wrong.\nAPI was: {url}')
+            raise AIHE.AIHClientException(f'Cannot interpret response as JSON. API might be wrong.\nAPI was: {url}\n\nResponse was:\n{response.text}')
         
 
     def _put(self, api:str, endpoint:str, data:dict):
@@ -154,14 +155,14 @@ class AIHClient:
                 response = self.client.post(url=url, data=json.dumps(data), headers=headers)
 
                 if response.status_code < 200 or response.status_code >= 300:
-                    raise AIHE.AIHClientException(f'POST request failed: {response.status_code}\n{response.text}')
+                    raise AIHE.AIHClientException(f'POST request failed: {response.status_code}\n{response.text}\n\nData was:\n{data}')
             else:
-                raise AIHE.AIHClientException(f'POST request failed: {response.status_code}\n{response.text}')
+                raise AIHE.AIHClientException(f'POST request failed: {response.status_code}\n{response.text}\n\nData was:\n{data}')
             
         try:
             return response.json()
         except:
-            raise AIHE.AIHClientException(f'Cannot interpret response as JSON. API might be wrong.\nAPI was: {url}')
+            raise AIHE.AIHClientException(f'Cannot interpret response as JSON. API might be wrong.\nAPI was: {url}\n\nResponse was:\n{response.text}')
             
             
     def _delete(self, api:str, endpoint:str, id:str):
@@ -270,7 +271,6 @@ class AIHClient:
         
         
         url = f'https://{self.environment}-aih-we-api.azurewebsites.net/api/v1/media'
-        #url = f'https://{self.environment}-aih-we-api.azurewebsites.net/api/v1/multimedia/upload/{container}'
         
         files = {'file' : (name, file)}
         
